@@ -54,8 +54,8 @@ class DocumentWidget : public QWidget, public KXMLGUIClient
 
 public:
     explicit DocumentWidget(const QUrl &file, const QStringList& customAllocators,
-                            KXMLGUIClient* guiParent, QWidget* parent = 0);
-    ~DocumentWidget();
+                            KXMLGUIClient* guiParent, QWidget* parent = nullptr);
+    ~DocumentWidget() override;
 
     Massif::FileData* data() const;
     QUrl file() const;
