@@ -64,8 +64,8 @@ class MainWindow : public KParts::MainWindow
     Q_OBJECT
 
 public:
-    MainWindow(QWidget* parent = 0, Qt::WindowFlags f = 0);
-    virtual ~MainWindow();
+    explicit MainWindow(QWidget* parent = nullptr, Qt::WindowFlags f = {});
+    ~MainWindow() override;
 
     void setupActions();
 
